==> lowcode-renderer-core-2.0.4.tgz: package/es/renderer/page.js <==
import _extends from "@babel/runtime/helpers/extends";
import _construct from "@babel/runtime/helpers/construct";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { getLogger } from '@gant-lowcode/lowcode-utils';
import baseRendererFactory from './base';
import { create as createDataSourceEngine } from '@alilc/lowcode-datasource-engine/interpret';
import adapter from '../adapter';
import { getI18n } from '../utils';
import { useMemo } from 'react';
var logger = getLogger({
  level: 'warn',
  bizName: 'renderer-core:page'
});
export default function pageRendererFactory() {
  var BaseRenderer = baseRendererFactory();
  var PageRenderer = /*#__PURE__*/function (_BaseRenderer) {
    function PageRenderer() {
      var _this;
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      _this = _BaseRenderer.call.apply(_BaseRenderer, [this].concat(args)) || this;
      _this.__namespace = 'page';
      return _this;
    }
    _inheritsLoose(PageRenderer, _BaseRenderer);
    var _proto = PageRenderer.prototype;
    _proto.__afterInit = function __afterInit(props) {
      this.__generateCtx({
        page: this
      });
      var schema = props.__schema || {};
      this.state = this.__parseData(schema.state || {});
      this.__initDataSource(props);
      for (var _len2 = arguments.length, rest = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        rest[_key2 - 1] = arguments[_key2];
      }
      this.__executeLifeCycleMethod('constructor', [props].concat(rest));
    };
    _proto.componentDidUpdate = /*#__PURE__*/function () {
      var _componentDidUpdate = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(prevProps, _prevState, snapshot) {
        var _BaseRenderer$prototy;
        var __ctx, newState;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              __ctx = this.props.__ctx; // 当编排的时候修改 schema.state 值，需要将最新 schema.state 值 setState
              if (JSON.stringify(prevProps.__schema.state) != JSON.stringify(this.props.__schema.state)) {
                newState = this.__parseData(this.props.__schema.state, __ctx);
                this.setState(newState);
              }
              (_BaseRenderer$prototy = _BaseRenderer.prototype.componentDidUpdate) === null || _BaseRenderer$prototy === void 0 ? void 0 : _BaseRenderer$prototy.call(this, prevProps, _prevState, snapshot);
            case 3:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function componentDidUpdate(_x, _x2, _x3) {
        return _componentDidUpdate.apply(this, arguments);
      }
      return componentDidUpdate;
    }();
    _proto.setState = function setState(state, callback) {
      logger.info('page set state', state);
      _BaseRenderer.prototype.setState.call(this, state, callback);
    };
    _proto.render = function render() {
      var _this$props = this.props,
        __schema = _this$props.__schema,
        __components = _this$props.__components;
      console.log('----PageRenderer', this);
      if (this.__checkSchema(__schema)) {
        return '页面schema结构异常！';
      }
      this.__debug(PageRenderer.displayName + " render - " + __schema.fileName);
      this.__bindCustomMethods(this.props);
      this.__initDataSource(this.props);
      this.__generateCtx({
        page: this
      });
      this.__render();
      var Page = __components.Page;
      if (Page) {
        return this.__renderComp(Page, {
          pageContext: this
        });
      }
      return this.__renderContent(this.__renderContextProvider({
        pageContext: this
      }));
    };
    return PageRenderer;
  }(BaseRenderer);
  PageRenderer.displayName = 'PageRenderer';
  var safeEval = function safeEval(code, context) {
    try {
      var _Object$entries$reduc = Object.entries(context).reduce(function (acc, _ref) {
          var key = _ref[0],
            value = _ref[1];
          acc.keys.push(key);
          acc.values.push(value);
          return acc;
        }, {
          keys: [],
          values: []
        }),
        keys = _Object$entries$reduc.keys,
        values = _Object$entries$reduc.values;
      // 显式包裹函数声明为表达式
      return _construct(Function, keys.concat(["return (" + code + ")"])).apply(void 0, values);
    } catch (error) {
      console.error('动态代码执行失败:', error);
      return undefined; // 或返回默认错误组件
    }
  };

  /**
   * 根据 schema 构建一个组件代码字符串
   * @param {Object} schema - 包含组件树和 statements 的 schema 对象
   */
  function generateComponentCode(schema) {
    var variables = [];
    // 提取 statements 数组，把每条语句拿出来（注意这里假定每条语句都是合法的 hook 调用或函数声明）
    var statementsCode = (schema.statements || []).map(function (stmt) {
      if (stmt.names) {
        stmt.names.forEach(function (name) {
          variables.push(name);
        });
      } else if (stmt.name) {
        variables.push(stmt.name);
      }
      return stmt.value;
    }).join('\n');
    // 生成完整的组件代码字符串
    var componentCode = "\n    function DynamicPageComponent(props) {\n      " + statementsCode + "\n      \n      return props.children({" + variables.join(',') + "});\n    }\n  ";
    return componentCode;
  }
  return function FunctionPageRenderer(props) {
    var _props$__appHelper2, _props$__appHelper3;
    console.log('FunctionPageRenderer---props', props);
    var defaultDataSource = {
      list: []
    };
    var dataSource = props.__schema.dataSource || defaultDataSource;
    var _adapter$hooks$useSta = adapter.hooks.useState(),
      state = _adapter$hooks$useSta[0],
      setState = _adapter$hooks$useSta[1];
    var dataSourceMap = useMemo(function () {
      var _props$__appHelper;
      var useDataSourceEngine = !!((_props$__appHelper = props.__appHelper) !== null && _props$__appHelper !== void 0 && _props$__appHelper.requestHandlersMap);
      console.log('--useDataSourceEngine', dataSource, useDataSourceEngine);
      if (useDataSourceEngine) {
        var _createDataSourceEngi = createDataSourceEngine(dataSource, {
            setState: setState
          }, props.__appHelper.requestHandlersMap ? {
            requestHandlersMap: props.__appHelper.requestHandlersMap
          } : undefined),
          _dataSourceMap = _createDataSourceEngi.dataSourceMap,
          reloadDataSource = _createDataSourceEngi.reloadDataSource;
        reloadDataSource();
        console.log('---dataSourceMap', _dataSourceMap);
        return _dataSourceMap;
      }
      return {};
    }, []);
    console.log('--state', state);
    var i18n = function i18n(key, values) {
      if (values === void 0) {
        values = {};
      }
      var locale = props.locale,
        messages = props.messages;
      return getI18n(key, values, locale, messages);
    };
    var getLocale = function getLocale() {
      return props.locale;
    };
    var setLocale = function setLocale(loc) {
      var _utils, _utils$i18n;
      var setLocaleFn = (_utils = utils) === null || _utils === void 0 ? void 0 : (_utils$i18n = _utils.i18n) === null || _utils$i18n === void 0 ? void 0 : _utils$i18n.setLocale;
      if (!setLocaleFn || typeof setLocaleFn !== 'function') {
        logger.warn('initI18nAPIs Failed, i18n only works when appHelper.utils.i18n.setLocale() exists');
        return undefined;
      }
      return setLocaleFn(loc);
    };
    var code = generateComponentCode(props.__schema);
    // console.log('---code', code);
    var CompiledComponent = safeEval(code, _extends({}, state, {
      dataSourceMap: dataSourceMap
    }, adapter.hooks, {
      props: props,
      i18n: i18n,
      setLocale: setLocale,
      getLocale: getLocale
    }, props.__appHelper, (_props$__appHelper2 = props.__appHelper) === null || _props$__appHelper2 === void 0 ? void 0 : _props$__appHelper2.hooks, {
      utils: (_props$__appHelper3 = props.__appHelper) === null || _props$__appHelper3 === void 0 ? void 0 : _props$__appHelper3.utils
    }));
    return adapter.runtime.createElement(CompiledComponent, {}, function (childrenProps) {
      return adapter.runtime.createElement(PageRenderer, _extends({
        childrenProps: childrenProps
      }, props));
    });
  };
}

==> lowcode-renderer-core-2.0.5.tgz: package/es/renderer/page.js <==
import _extends from "@babel/runtime/helpers/extends";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import { getLogger } from '@gant-lowcode/lowcode-utils';
import baseRendererFactory from './base';
import { create as createDataSourceEngine } from '@alilc/lowcode-datasource-engine/interpret';
import adapter from '../adapter';
import { generateComponentCode, getAgnosticComponent, getI18n } from '../utils';
var logger = getLogger({
  level: 'warn',
  bizName: 'renderer-core:page'
});
export default function pageRendererFactory() {
  var BaseRenderer = baseRendererFactory();
  var PageRenderer = /*#__PURE__*/function (_BaseRenderer) {
    function PageRenderer() {
      var _this;
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      _this = _BaseRenderer.call.apply(_BaseRenderer, [this].concat(args)) || this;
      _this.__namespace = 'page';
      return _this;
    }
    _inheritsLoose(PageRenderer, _BaseRenderer);
    var _proto = PageRenderer.prototype;
    _proto.__afterInit = function __afterInit(props) {
      this.__generateCtx({
        page: this
      });
    };
    _proto.render = function render() {
      var _this$props = this.props,
        __schema = _this$props.__schema,
        __components = _this$props.__components;
      if (this.__checkSchema(__schema)) {
        return '页面schema结构异常！';
      }
      this.__debug(PageRenderer.displayName + " render - " + __schema.fileName);
      this.__generateCtx({
        page: this
      });
      this.__render();
      var Page = __components.Page;
      console.log('---Page', __components, Page);
      if (Page) {
        return this.__renderComp(Page, {
          pageContext: this
        });
      }
      return this.__renderContent(this.__renderContextProvider({
        pageContext: this
      }));
    };
    return PageRenderer;
  }(BaseRenderer);
  PageRenderer.displayName = 'PageRenderer';
  return function FunctionPageRenderer(props) {
    var _props$__appHelper2, _props$__appHelper3, _props$__appHelper4;
    var defaultDataSource = {
      list: []
    };
    console.log('FunctionPageRenderer--props', props);
    var dataSource = props.__schema.dataSource || defaultDataSource;
    var _adapter$hooks$useSta = adapter.hooks.useState(),
      state = _adapter$hooks$useSta[0],
      setState = _adapter$hooks$useSta[1];
    var dataSourceMap = adapter.hooks.useMemo(function () {
      var _props$__appHelper;
      var useDataSourceEngine = !!((_props$__appHelper = props.__appHelper) !== null && _props$__appHelper !== void 0 && _props$__appHelper.requestHandlersMap);
      if (useDataSourceEngine) {
        var _createDataSourceEngi = createDataSourceEngine(dataSource, {
            setState: setState
          }, props.__appHelper.requestHandlersMap ? {
            requestHandlersMap: props.__appHelper.requestHandlersMap
          } : undefined),
          _dataSourceMap = _createDataSourceEngi.dataSourceMap,
          reloadDataSource = _createDataSourceEngi.reloadDataSource;
        reloadDataSource();
        return _dataSourceMap;
      }
      return {};
    }, []);
    var i18n = function i18n(key, values) {
      if (values === void 0) {
        values = {};
      }
      var locale = props.locale,
        messages = props.messages;
      return getI18n(key, values, locale, messages);
    };
    var getLocale = function getLocale() {
      return props.locale;
    };
    var setLocale = function setLocale(loc) {
      var _utils, _utils$i18n;
      var setLocaleFn = (_utils = utils) === null || _utils === void 0 ? void 0 : (_utils$i18n = _utils.i18n) === null || _utils$i18n === void 0 ? void 0 : _utils$i18n.setLocale;
      if (!setLocaleFn || typeof setLocaleFn !== 'function') {
        logger.warn('initI18nAPIs Failed, i18n only works when appHelper.utils.i18n.setLocale() exists');
        return undefined;
      }
      return setLocaleFn(loc);
    };
    var code = generateComponentCode(props.__schema);
    // console.log('---code', code);
    var CompiledComponent = getAgnosticComponent(code, _extends({}, state, {
      dataSourceMap: dataSourceMap
    }, adapter.hooks, {
      props: props,
      i18n: i18n,
      setLocale: setLocale,
      getLocale: getLocale
    }, props.__appHelper, (_props$__appHelper2 = props.__appHelper) === null || _props$__appHelper2 === void 0 ? void 0 : _props$__appHelper2.system, (_props$__appHelper3 = props.__appHelper) === null || _props$__appHelper3 === void 0 ? void 0 : _props$__appHelper3.hooks, {
      utils: (_props$__appHelper4 = props.__appHelper) === null || _props$__appHelper4 === void 0 ? void 0 : _props$__appHelper4.utils
    }));
    return adapter.runtime.createElement(CompiledComponent, {}, function (__runtimeScope__) {
      return adapter.runtime.createElement(PageRenderer, _extends({
        __runtimeScope__: __runtimeScope__
      }, props));
    });
  };
}
